pg.ddx.io pgsql-performance@postgresql.org mailing list archive
help / color / mirror / Atom feed From: Ian Westmacott <ianw@intellivid.com>
To: Tom Lane <tgl@sss.pgh.pa.us>
Cc: pgsql-performance@postgresql.org
Subject: Re: Why hash join instead of nested loop?
Date: Tue, 09 Aug 2005 08:15:56 -0400
Message-ID: <1123589756.15206.4.camel@spectre.intellivid.com> (raw )
In-Reply-To: <10930.1123549106@sss.pgh.pa.us >
References: <41b0fe890508051135712a086b@mail.gmail.com >
<001801c59a0a$f4be7480$9a00a8c0@OTTO >
<41b0fe8905080516164464e04f@mail.gmail.com >
<15425.1123304631@sss.pgh.pa.us >
<41b0fe89050808100021a2a4fc@mail.gmail.com >
<10930.1123549106@sss.pgh.pa.us >
On Mon, 2005-08-08 at 20:58, Tom Lane wrote:
> I'd be interested to see results from other people using 7.4.* too.
7.4.8:
QUERY
PLAN
----------------------------------------------------------------------------------------------------------------------------------------------------
Hash Join (cost=4.83..5.91 rows=1 width=14) (actual time=0.122..0.126
rows=1 loops=1)
Hash Cond: ("outer".id = "inner".obj2)
-> Seq Scan on rtmessagestate (cost=0.00..1.05 rows=5 width=14)
(actual time=0.003..0.006 rows=5 loops=1)
-> Hash (cost=4.83..4.83 rows=1 width=4) (actual time=0.021..0.021
rows=0 loops=1)
-> Index Scan using connection_regid_obj1_index on connection
(cost=0.00..4.83 rows=1 width=4) (actual time=0.013..0.015 rows=1
loops=1)
Index Cond: ((connection_registry_id = 40105) AND (obj1 =
73582))
Total runtime: 0.198 ms
7.4.2:
QUERY
PLAN
----------------------------------------------------------------------------------------------------------------------------------------------------
Hash Join (cost=4.83..5.91 rows=1 width=14) (actual time=0.577..0.600
rows=1 loops=1)
Hash Cond: ("outer".id = "inner".obj2)
-> Seq Scan on rtmessagestate (cost=0.00..1.05 rows=5 width=14)
(actual time=0.006..0.023 rows=5 loops=1)
-> Hash (cost=4.83..4.83 rows=1 width=4) (actual time=0.032..0.032
rows=0 loops=1)
-> Index Scan using connection_regid_obj1_index on connection
(cost=0.00..4.83 rows=1 width=4) (actual time=0.016..0.020 rows=1
loops=1)
Index Cond: ((connection_registry_id = 40105) AND (obj1 =
73582))
Total runtime: 0.697 ms
--Ian
view thread (18+ messages) latest in thread
Message-ID: <1123589756.15206.4.camel@spectre.intellivid.com>
Permalink: ../1123589756.15206.4.camel@spectre.intellivid.com/
Also on: postgresql.org/message-id/1123589756.15206.4.camel@spectre.intellivid.com
copy link · copy postgr.es
reply Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-performance@postgresql.org
Cc: ianw@intellivid.com, tgl@sss.pgh.pa.us
Subject: Re: Why hash join instead of nested loop?
In-Reply-To: <1123589756.15206.4.camel@spectre.intellivid.com>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox